@@ -22,6 +22,7 @@ from typing import (
     Union,
 )
 import dataclasses
+import datetime
 import io
 import itertools
 import json
@@ -462,7 +463,7 @@ class Collection:
                       partitioning=self.partitioning.get_config())
 
         with self.fs.open(config, mode='w') as stream:
-            json.dump(params, stream, indent=4)
+            json.dump(params, stream, indent=4)  # type: ignore[arg-type]
 
     def is_readonly(self) -> bool:
         """Return True if the collection is read-only."""
@@ -644,6 +645,7 @@ class Collection:
         self,
         *,
         filters: PartitionFilter = None,
+        timedelta: datetime.timedelta | None = None,
     ) -> None:
         # pylint: disable=method-hidden
         """Drop the selected partitions.
@@ -652,12 +654,25 @@ class Collection:
             filters: The predicate used to filter the partitions to drop.
                 To get more information on the predicate, see the
                 documentation of the :meth:`partitions` method.
+            timedelta: Select the partitions created before the
+                specified time delta relative to the current time.
 
         Example:
             >>> collection.drop_partitions(filters="year == 2019")
+            >>> collection.drop_partitions(
+            ...     timedelta=datetime.timedelta(days=30))
         """
+        now = datetime.datetime.now()
         client = utilities.get_client()
         folders = list(self.partitions(filters=filters))
+
+        def is_created_before(path: str) -> bool:
+            created = self.fs.created(path)
+            return now - created > timedelta
+
+        if timedelta is not None:
+            folders = list(filter(is_created_before, folders))
+
         storage.execute_transaction(
             client, self.synchronizer,
             client.map(self.fs.rm, folders, recursive=True))
@@ -1082,9 +1097,10 @@ class Collection:
         Returns
             The iterator over the partitions and the zarr groups.
         """
-        for item in self.partitions():
-            yield (self._relative_path(item) if relative else item,
-                   zarr.open_consolidated(self.fs.get_mapper(item)))
+        yield from (
+            (self._relative_path(item) if relative else item,
+             zarr.open_consolidated(self.fs.get_mapper(item)))  # type: ignore
+            for item in self.partitions())
 
     def variables(
         self,
